/*
 * This Software (C) Copyright David Goodwin, 2008, 2009.
 * 
 *   This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package iasel;

import iasel.data.AreaProfile;
import java.io.File;
import java.io.FileReader;
import java.util.ArrayList;
import javax.swing.JOptionPane;
import org.ini4j.Ini;
import org.ini4j.Ini.Section;

/** Loads the Area Profile configuration file.
 *
 * @author David Goodwin
 */
public class AreaFile {
    private Ini sINIFile;
    
    public AreaFile() {
        try {
            sINIFile = new Ini(new FileReader(new File(globals.areaFileName)));
        } catch (Exception e) {
            JOptionPane.showMessageDialog(null, "Unable to open Area " +
                    "Profile information file. Area computations will be " +
                    "disabled for this session.", "Could not open file",
                    JOptionPane.ERROR_MESSAGE);
            globals.AreaCalcEnable = false;
        }
    }
    
    public ArrayList<AreaProfile> getProfiles() {
        // First, figure out how many profiles there are
        int profileCount = 
                Integer.parseInt(getValue("information\\entries","0"));
        
        // Create a list to hold the profiles
        ArrayList<AreaProfile> apal = new ArrayList<AreaProfile>();
        
        // If there are no profiles then just return the empty list
        if (profileCount == 0)
            return apal;
        
        // There are profiles. We must now load in each one.        
        for (int i = 1; i < profileCount+1; i++) {
            AreaProfile a = new AreaProfile();
            a.short_name = getValue(i + "\\short-name","!~$)@");
            a.display_name = getValue(i + "\\display-name","!~$)@");
            a.depth = Double.parseDouble(getValue(i + "\\depth","0"));
            a.width = Double.parseDouble(getValue(i + "\\width","0"));
            
            if (!a.short_name.equalsIgnoreCase("!~$)@") &&
                    !a.display_name.equalsIgnoreCase("!~$)@"))
                apal.add(a);
        }
        
        return apal;
    }
    
    /** Gets a key from the settings file.
     * @param key The key to get the value for.
     * @param sDefaultValue The value to return if either the key, or the value does not exist.
     * @return The value of the specified key.
     */
    private String getValue(final String key, final String sDefaultValue) {
        String tmp;
        String sectName;
        String keyName;
        if (sINIFile == null) {
            return sDefaultValue;
        }
        Section sect = sINIFile.new Section("");
        
        /* Figure out the section and key names from the input value */
        final String[] parts = key.split("[\\\\]");
        if (parts.length > 1) {
            sectName = parts[0];
            keyName = parts[1];
        } else if (parts.length == 1) {
            sectName = "general";
            keyName = parts[0];
        } else {
            return sDefaultValue;
        }
         
        /* Make sure our input parameters are allowed */
        if(key == null || sDefaultValue == null) {
            return null;
        }
        
        sect = sINIFile.get(sectName);
        
        /* If the section doesn't exist, return the default value. */
        if(sect == null) {
            return sDefaultValue;
        }
        
        /* Now try and get the key value*/
        tmp = sect.get(keyName);

        /* If the key doesn't exist, return the default value*/
        if(tmp == null) {
            tmp = sDefaultValue;
        }
        
        /* Return the result. */
        return tmp;
    }        
}
