/*
 * This Software (C) Copyright David Goodwin, 2008, 2009.
 * 
 *   This is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 * 
 *  This software is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this software; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

package iasel.gui;

import iasel.data.REntry;
import java.util.ArrayList;
import javax.swing.JOptionPane;
import javax.swing.ListSelectionModel;
import javax.swing.table.DefaultTableModel;

/** This widget provides a simple results table.
 *
 * @author  David
 */
public class ResultsTable extends javax.swing.JPanel {
    
    private DefaultTableModel dtm;
    
    private ArrayList<REntry> entries = new ArrayList<REntry>();
    
    /** Creates new form ResultsTable */
    public ResultsTable() {
        initComponents();
        dtm = (DefaultTableModel)resultsDisplay.getModel();
        ListSelectionModel lsm = resultsDisplay.getSelectionModel();
        lsm.setSelectionInterval(0,0);
        lsm.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
    }
    
    public void addRow(REntry e) {
        entries.add(e);
        dtm.addRow(e.getData());
        updateRowCount();
    }
    
    public void updateRowCount() {
        lblItemCount.setText(Integer.toString(dtm.getRowCount()));
    }
    
    public ArrayList<REntry> getRows() {
        return entries;
    }
    
    public void clearResults() {
        int result = JOptionPane.showConfirmDialog(null,"Really clear ALL results?", "Confirm", JOptionPane.OK_CANCEL_OPTION);
        if (result == JOptionPane.OK_OPTION) {
            entries.clear();
            int j = dtm.getRowCount();
            for (int i = 0; i < j; i++)
            dtm.removeRow(0);            
        }
        updateRowCount();
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        jScrollPane1 = new javax.swing.JScrollPane();
        resultsDisplay = new javax.swing.JTable();
        jPanel1 = new javax.swing.JPanel();
        jLabel1 = new javax.swing.JLabel();
        lblItemCount = new javax.swing.JLabel();

        setName("Form"); // NOI18N
        setLayout(new java.awt.BorderLayout());

        jScrollPane1.setName("jScrollPane1"); // NOI18N

        resultsDisplay.setModel(new javax.swing.table.DefaultTableModel(
            new Object [][] {

            },
            new String [] {
                "Filename", "Tag", "Frame Pixels", "Selected Pixels", "Selected Percentage", "Selected Area (cm^2)", "Area Type"
            }
        ) {
            boolean[] canEdit = new boolean [] {
                false, false, false, false, false, false, false
            };

            public boolean isCellEditable(int rowIndex, int columnIndex) {
                return canEdit [columnIndex];
            }
        });
        resultsDisplay.setName("resultsDisplay"); // NOI18N
        jScrollPane1.setViewportView(resultsDisplay);

        add(jScrollPane1, java.awt.BorderLayout.CENTER);

        jPanel1.setName("jPanel1"); // NOI18N

        org.jdesktop.application.ResourceMap resourceMap = org.jdesktop.application.Application.getInstance(iasel.Iasel.class).getContext().getResourceMap(ResultsTable.class);
        jLabel1.setText(resourceMap.getString("jLabel1.text")); // NOI18N
        jLabel1.setName("jLabel1"); // NOI18N
        jPanel1.add(jLabel1);

        lblItemCount.setText(resourceMap.getString("lblItemCount.text")); // NOI18N
        lblItemCount.setName("lblItemCount"); // NOI18N
        jPanel1.add(lblItemCount);

        add(jPanel1, java.awt.BorderLayout.PAGE_END);
    }// </editor-fold>//GEN-END:initComponents
    
    
    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel jLabel1;
    private javax.swing.JPanel jPanel1;
    private javax.swing.JScrollPane jScrollPane1;
    private javax.swing.JLabel lblItemCount;
    private javax.swing.JTable resultsDisplay;
    // End of variables declaration//GEN-END:variables
    
}
